@@ -6,7 +6,7 @@ use warnings;
 
 use Fcntl ':flock';
 
-our $VERSION = '0.48'; # VERSION
+our $VERSION = '0.49'; # VERSION
 
 sub lock {
     my ($class, $path, $opts) = @_;
@@ -15,7 +15,7 @@ sub lock {
 
     defined($path) or die "Please specify path";
     $h{path}    = $path;
-    $h{unlink}  = $opts->{unlink}  //  0;
+    $h{unlink}  = $opts->{unlink}  //  1;
     $h{retries} = $opts->{retries} // 60;
 
     my $self = bless \%h, $class;
@@ -78,9 +78,16 @@ sub _unlock {
 
     my $path = $self->{path};
 
+    # don't unlock if we are not holding the lock
     return 0 unless $self->{_fh};
+
+    unlink $self->{path} if $self->{unlink};
+
     {
-        no warnings; # to shut up warning about flock on closed filehandle
+        # to shut up warning about flock on closed filehandle (XXX but why
+        # closed if we are holding the lock?)
+        no warnings;
+
         flock $self->{_fh}, LOCK_UN;
     }
     close delete($self->{_fh});
@@ -99,7 +106,6 @@ sub unlock {
 
 sub DESTROY {
     my $self = shift;
-    unlink $self->{path} if $self->{_fh} && $self->{unlink};
     $self->_unlock;
 }
 
@@ -118,7 +124,7 @@ SHARYANTO::File::Flock - Yet another flock module
 
 =head1 VERSION
 
-version 0.48
+version 0.49
 
 =head1 SYNOPSIS
 
@@ -127,15 +133,12 @@ version 0.48
  # try to acquire exclusive lock. if fail to acquire lock within 60s, die.
  my $lock = SHARYANTO::File::Flock->lock($file);
 
- # automatically release the lock if object is DESTROY-ed.
- undef $lock;
-
- # set number of retries and unlink lock file during DESTROY.
- $lock = SHARYANTO::File::Flock->lock($path, {retries=>30, unlink=>1});
-
  # explicitly unlock
  $lock->release;
 
+ # automatically unlock if object is DESTROY-ed.
+ undef $lock;
+
 =head1 DESCRIPTION
 
 This is yet another flock module. The name (under SHARYANTO:: namespace) is
@@ -144,7 +147,7 @@ different in the following ways:
 
 =over 4
 
-=item * Can be instructed to unlink the lock file during DESTROY
+=item * Can be instructed to unlink the lock file upon release
 
 =item * Does retries (by default for 60s) when trying to acquire lock
 
@@ -168,10 +171,13 @@ Available options:
 
 =over
 
-=item * unlink => BOOL (default: 0)
+=item * unlink => BOOL (default: 1)
 
-If set to true, will unlink C<$path> when unlinking. This is convenient to clean
-lock files.
+If set to true, will unlink C<$path> when releasing the lock. This is convenient
+to clean created lock files, and so is the default behavior.
+
+If set to false, will not unlink lock files. You'll need to remove lock files
+manually.
 
 =item * retries => INT (default: 60)
 
@@ -190,7 +196,7 @@ Synonym for unlock().
 =head2 DESTROY
 
 When C<unlink> option is set to true, will unlink lock file during object
-destruction. Will only do so if current process holds the lock.
+destruction. Will only do so if current process is holding the lock.
 
 =head1 CAVEATS
 
